@@ -24,10 +24,14 @@
 #ifndef GLMARK2_TEXTURE_H_
 #define GLMARK2_TEXTURE_H_
 
-#include "oglsdl.h"
+#include "gl-headers.h"
 
-#include <stdio.h>
+#include <string>
 
-int load_texture(const char pFilename[], GLuint *pTexture);
+class Texture
+{
+public:
+    static int load(const std::string &filename, GLuint *pTexture, ...);
+};
 
 #endif
